import Toolbar from './toolbar'
import h from 'virtual-dom/h'
import RenderTree from 'render-tree'
import AppMenu from 'app-menu'
import ThumbnailList from 'forecaster/thumbnail_list'
import Products from 'forecaster/user_products'
import Projections from 'forecaster/user_projections'
import eccharts from 'eccharts-2'

var fns = [
	function(){
		var el = document.querySelector('#toolbar');

		var vdom = new RenderTree({
			root: el,
			main: {
				render: function() {
					return toolbar.render()
				}
			}
		})

		var toolbar = new Toolbar({
			renderer: vdom
		})

		vdom.render()
	},

	function(){
		// app-menu

		var menu = document.querySelector('#app-menu');
		var chart = eccharts.chart()

		var r = new RenderTree({
			root: menu.appendChild(document.createElement('div')),
			main: {
				render: function() {
					return h('.panels', [
						panels.products.render(),
						panels.projections.render(),
					])
				}
			},
			items: {
			}
		})

		var panels = {
			products: new ThumbnailList({
				products: Products,
				renderer: r,
				onclick: chart.bind(chart.set_product)
			}),
			projections: new ThumbnailList({
				products: Projections,
				renderer: r,
				onclick: chart.bind(chart.set_projection)
			})
		}

		function deactivate() {
			Object.keys(panels).forEach(function(v){ panels[v].active = false })
		}
		deactivate()

		r.render()

		function toggle(e, panel) {
			var active = !panel.active
			deactivate()
			panel.active = active;

			r.render()
			e.stopPropagation()
			e.preventDefault(); // TODO do this in the appmenu
		}

		var a = new RenderTree({
			root: document.querySelector('body').appendChild(document.createElement('div')),
			main: {
				render: function() {
					return h('#eccharts', Object.keys(views).map(function(v){
						var name = v.replace(' ', '-').toLowerCase()
						return views[v]
							? views[v].render()
							: h('.' + name)
					}))
				}
			}
		})

		var views = {
			Probe: null,
			Cities: null,
			Meteograms: null,
			'Time series': null,
			Info: null,
			Legends: null,
			'Vertical profiles': null
		}

		a.render();

		var items = [
			{
				title: 'Products',
				onclick: function(e) {
					toggle(e, panels.products)
				},
				items: [
					{}
				]
			},
			{
				title: 'Projections',
				onclick: function(e) {
					toggle(e, panels.projections)
				},
				items: [{}]
			},
			{
				title: 'Views',
				items: function() {
					return Object.keys(views).map(function(item) {
						var view = views[item]
						var selected = view && view.dialogue._open
						return h('li' + (selected ? '.selected' : ''), [
							h('a' + (selected ? '.ui-icon.ui-icon-check' : ''), {
								href: '#' + css_name(item),
								onclick: function(e) {
									require(['./view'], function(View) {
										if(view){
											view.dialogue[selected ? 'close' : 'open']()
										}else{
											views[item] = new View.default({title: item, renderer: a})
										}
										a.render()
										menu.render()
									})
									e.preventDefault();
								}
							}, [item])
						])
					})
				}
			}
		]

		var el = document.querySelector('#app-menu .row');

		var menu = new AppMenu({
			el: el,
			items: items,
			help: [{
				name: 'help',
				title: 'Help',
				items: [
					{title: 'FAQ', href: '/search/faqs?f[0]=im_field_faq_category%3A1082'},
				]
			}]
		})
		menu.render();
	},

	function(){
		require(['theme-ecmwf-2017/bootstrap/index'])
	},
]

var i = -1;
(function next(){
	var fn = fns[++i];
	fn && setTimeout(function(){
		fn()
		next()
	}, 10)
})()

function css_name(name){
	return name.replace(' ', '-').toLowerCase();
}

